==> cxroots-1.1.3.tar.gz: cxroots-1.1.3/setup.py <==
#!/usr/bin/env python
import os
import sys
import shutil
import unittest
from setuptools import setup
from setuptools.command.test import test as TestCommand # Need for 'test' command to be recognised
from numpy.distutils.misc_util import get_numpy_include_dirs

packages = ['cxroots', 'cxroots.tests', 'cxroots.contours']

# get the version, this will assign __version__
exec(open('cxroots/version.py').read())

# read the README_pip.rst
try:
    with open('README.rst') as file:
        long_description = file.read()
except:
    long_description = None

setup(
    name = 'cxroots',
    version = __version__,
    description = 'Find all the roots (zeros) of a complex analytic function within a given contour in the complex plane.',
    long_description = long_description,
    author = 'Robert Parini',
    author_email = 'robert.parini@gmail.com',
    url = 'https://rparini.github.io/cxroots/',
    license = 'BSD',
    data_files = [("", ["LICENSE"])],
    packages = packages,
    zip_safe = False,   # prevent cxroots from installing as a .egg zip file
    platforms = ['all'],
    dependency_links=['git+git://github.com/pbrod/numdifftools'],
    setup_requires = ['pytest-runner'],
    install_requires = ['numpy', 'scipy', 'docrep', 'mpmath', 'numdifftools'],
    tests_require=['pytest', 'pytest-xdist'],
    keywords='roots zeros complex analytic functions',
    classifiers=[
	    'Development Status :: 4 - Beta',
	    'Intended Audience :: Science/Research',
	    'Topic :: Scientific/Engineering :: Mathematics',
	    'License :: OSI Approved :: BSD License',
	    'Programming Language :: Python :: 2.7',
	    'Programming Language :: Python :: 3',
	],
)

==> cxroots-1.1.8.tar.gz: cxroots-1.1.8/setup.py <==
#!/usr/bin/env python
from setuptools import setup

packages = ['cxroots', 'cxroots.tests', 'cxroots.contours']

# get the version, this will assign __version__
exec(open('cxroots/version.py').read())

# read the README_pip.rst
try:
    with open('README.rst') as file:
        long_description = file.read()
except IOError:
    long_description = None

setup(
    name = 'cxroots',
    version = __version__,
    description = 'Find all the roots (zeros) of a complex analytic function within a given contour in the complex plane.',
    long_description = long_description,
    author = 'Robert Parini',
    author_email = 'robert.parini@gmail.com',
    url = 'https://rparini.github.io/cxroots/',
    license = 'BSD',
    data_files = [("", ["LICENSE"])],
    packages = packages,
    zip_safe = False,   # prevent cxroots from installing as a .egg zip file
    platforms = ['all'],
    dependency_links=['git+https://github.com/rparini/numdifftools.git@fix_vstack_futurewarning#egg=numdifftools'],
    setup_requires = ['pytest-runner'],
    install_requires = ['numpy', 'scipy', 'docrep', 'mpmath', 'numdifftools'],
    tests_require=['pytest'],
    keywords='roots zeros complex analytic functions',
    classifiers=[
	    'Development Status :: 4 - Beta',
	    'Intended Audience :: Science/Research',
	    'Topic :: Scientific/Engineering :: Mathematics',
	    'License :: OSI Approved :: BSD License',
	    'Programming Language :: Python :: 2.7',
	    'Programming Language :: Python :: 3',
	],
)
